==> trivy-0.51.1.tar.zst: trivy-0.51.1/pkg/iac/scanners/azure/functions/equals_test.go <==
package functions

import (
	"testing"

	"github.com/stretchr/testify/assert"
)

func Test_Equals(t *testing.T) {
	tests := []struct {
		name     string
		args     []interface{}
		expected interface{}
	}{
		{
			name: "equals with nil",
			args: []interface{}{
				nil,
			},
			expected: false,
		},
		{
			name: "equals with nil and string",
			args: []interface{}{
				nil,
				"test",
			},
			expected: false,
		},
		{
			name: "equals with nil and string and int",
			args: []interface{}{
				nil,
				"test",
				1,
			},
			expected: false,
		},
		{
			name: "equals with nil and nil and array",
			args: []interface{}{
				nil,
				nil,
				[]interface{}{"a", "b", "c"},
			},
			expected: false,
		},
		{
			name: "equals with nil and nil",
			args: []interface{}{
				nil,
				nil,
			},
			expected: true,
		},
		{
			name: "equals with string and string",
			args: []interface{}{
				"test",
				"test",
			},
			expected: true,
		},
		{
			name: "equals with string and string",
			args: []interface{}{
				"test",
				"test1",
			},
			expected: false,
		},
		{
			name: "equals with int and int",
			args: []interface{}{
				1,
				1,
			},
			expected: true,
		},
		{
			name: "equals with int and int",
			args: []interface{}{
				1,
				2,
			},
			expected: false,
		},
		{
			name: "equals with array and array",
			args: []interface{}{
				[]interface{}{"a", "b", "c"},
				[]interface{}{"a", "b", "c"},
			},
			expected: true,
		},
		{
			name: "equals with array and array",
			args: []interface{}{
				[]interface{}{"a", "b", "c"},
				[]interface{}{"a", "b", "d"},
			},
			expected: false,
		},
	}
	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			actual := Equals(tt.args...)
			assert.Equal(t, tt.expected, actual)
		})
	}
}

==> trivy-0.59.1.tar.zst: trivy-0.59.1/pkg/iac/scanners/azure/functions/equals_test.go <==
package functions

import (
	"testing"

	"github.com/stretchr/testify/assert"
)

func Test_Equals(t *testing.T) {
	tests := []struct {
		name     string
		args     []any
		expected any
	}{
		{
			name: "equals with nil",
			args: []any{
				nil,
			},
			expected: false,
		},
		{
			name: "equals with nil and string",
			args: []any{
				nil,
				"test",
			},
			expected: false,
		},
		{
			name: "equals with nil and string and int",
			args: []any{
				nil,
				"test",
				1,
			},
			expected: false,
		},
		{
			name: "equals with nil and nil and array",
			args: []any{
				nil,
				nil,
				[]any{"a", "b", "c"},
			},
			expected: false,
		},
		{
			name: "equals with nil and nil",
			args: []any{
				nil,
				nil,
			},
			expected: true,
		},
		{
			name: "equals with string and string",
			args: []any{
				"test",
				"test",
			},
			expected: true,
		},
		{
			name: "equals with string and string",
			args: []any{
				"test",
				"test1",
			},
			expected: false,
		},
		{
			name: "equals with int and int",
			args: []any{
				1,
				1,
			},
			expected: true,
		},
		{
			name: "equals with int and int",
			args: []any{
				1,
				2,
			},
			expected: false,
		},
		{
			name: "equals with array and array",
			args: []any{
				[]any{"a", "b", "c"},
				[]any{"a", "b", "c"},
			},
			expected: true,
		},
		{
			name: "equals with array and array",
			args: []any{
				[]any{"a", "b", "c"},
				[]any{"a", "b", "d"},
			},
			expected: false,
		},
	}
	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			actual := Equals(tt.args...)
			assert.Equal(t, tt.expected, actual)
		})
	}
}
